#ifndef HYPOZYCLOID_X_FO_H
#define HYPOZYCLOID_X_FO_H

#include <math.h>
#include "Types.h"
#include "Helpers.h"

// Template function object class which calculates the x-coordinate
// of a point at a hypozycloid for a given parameter value t
// Parameters:
//    NumType_    the number type of the points coordinates
template <class NumType_> 
class Hypozykloide_x {

public:
    typedef CGAL::Cartesian<NumType_> REP;
    typedef CGAL::Point_2<REP> Point;
    typedef list<Point> PointList;
    typedef vector<Point> Points; 
    
    static const double PI = 3.14159265;    

    Hypozykloide_x(const Point& center=CGAL::ORIGIN, NumType_ radius1 = 1, 
		   NumType_ radius2 = 4, NumType_ a = 1) {
	center_ = center;
	r_ = radius1;
	r2_ = radius2;
	a_ = a;
    }    

    NumType_ operator() (NumType_ t) const {
	return (center_.x() + (r2_-r_)*cos(_to_float(t)) + 
		a_*cos(_to_float(((r2_-r_)/r_)*t)));
    }

private:
    Point center_;
    NumType_ r_;
    NumType_ r2_;
    NumType_ a_;
};
#endif //HYPOZYCLOID_X_FO_H
