#ifndef CGAL_X_FO_H
#define CGAL_X_FO_H

#include "Types.h"
#include "Curve_constants.h"
#include "Helpers.h"
#include "DeCasteljau_FO.h"


// Template function object which returns the x-coordinate of a given point
// Parameters:
//   NumType_      number type for coordinates
//   A_            the type of the algorithm which calculates for a 
//                 given parameter value t the appropriate point on curve  
template <class NumType_, class A_=DeCasteljau_FO<NumType_>* > 
class X_FO {
public:
    typedef A_ A;
    typedef NumType_ NumType;
    typedef CGAL::Cartesian<NumType> REP;
    typedef CGAL::Point_2<REP> Point;   
    typedef vector<Point> Points;    

    X_FO() : alg() {
    }

    X_FO(A algorithm) : alg(algorithm) {
    }    

    NumType operator() (NumType t) const {
	return ((*alg)(t)).x();
    }     

private:
    // pointer to the function object alg: t -> Point
    A alg;   
    
};
#endif //CGAL_X_FO_H

