#ifndef CGAL_ZYCLOID_Y_FO_H
#define CGAL_ZYCLOID_Y_FO_H

#include <math.h>
#include "Types.h"
#include "Helpers.h"


// Template function object class which calculates the y-coordinate
// of a point at a zycloid for a given parameter value t
// Parameters:
//    NumType_    the number type of the points coordinates
template <class NumType_> 
class Zykloide_y {

public:
    typedef CGAL::Cartesian<NumType_> REP;
    typedef CGAL::Point_2<REP> Point;
    typedef list<Point> PointList;
    typedef vector<Point> Points; 
    
    static const double PI = 3.14159265;
    
    Zykloide_y(const Point& center=CGAL::ORIGIN, NumType_ radius = 1, NumType_ a = 1) {
	center_ = center;
	r_ = radius;
	a_ = a;
    }    

    NumType_ operator() (NumType_ t) const {
	return (center_.y() + r_ - a_*cos(_to_float(t)));
    }

private:
    Point center_;
    NumType_ r_;
    NumType_ a_;
};
#endif //CGAL_ZYCLOID_Y_FO_H
